.. module:: pymeasure.instruments.lecroy

########
LeCroy
########

This section contains specific documentation on the LeCroy instruments that are implemented. If you are interested in an instrument not included, please consider :doc:`adding the instrument </dev/adding_instruments/index>`.

If the instrument you are looking for is not here, also check :doc:`Teledyne<../teledyne/index>` for newer instruments. 

.. toctree::
   :maxdepth: 2

   lecroyT3DSO1204